nibabel: Access a multitude of neuroimaging data formats
========================================================

Description
-----------

Access a multitude of neuroimaging data formats

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/nibabel/

